gp2c: A compiler for translating GP routines to C
=================================================

Description
-----------

The gp2c compiler is a package for translating GP routines into the C
programming language, so that they can be compiled and used with the
PARI system or the GP calculator.

License
-------

GPL version 2+


Upstream Contact
----------------

-  http://pari.math.u-bordeaux.fr/

Dependencies
------------

-  PARI
-  Perl
